<?php


namespace Sikofitt\Form\Type;

use Symfony\Component\Form\{
    FormBuilderInterface, AbstractType, Extension\Core\Type\SubmitType, Extension\Core\Type\EmailType, Extension\Core\Type\TextareaType, Extension\Core\Type\TextType, FormConfigInterface, FormInterface
};

use Symfony\Component\Security\Csrf\CsrfToken;
use Symfony\Component\Validator\Constraints\{
    Email,
    Length,
    NotBlank
};

use Symfony\Component\OptionsResolver\OptionsResolver;


/**
 * Class ContactType
 * @package Sikofitt\Form\Type
 */
class ContactType extends AbstractType
{


    /**
     * @param FormBuilderInterface $builder
     * @param array $options
     */
    public function buildForm (FormBuilderInterface $builder, array $options)
    {
        $builder
            ->add('name', TextType::class, [
                'constraints' => [
                    new Length([
                            'min' => 5]
                    ),
                    new NotBlank(),
                ],
                'attr' => [
                    'class' => 'uk-form-large uk-width-1-1',
                    'placeholder' => 'Your name',
                ],
                'label' => 'Name',
                'label_attr' => [
                    'class' => 'uk-form-label',
                ],
            ])
            ->add('email', EmailType::class, [
                'constraints' => [
                    new NotBlank(),
                    new Email(),
                ],
                'attr' => [
                    'class' => 'uk-form-large uk-width-1-1',
                    'placeholder' => 'Email address',
                ],
                'label' => 'Email',
                'label_attr' => [
                    'class' => 'uk-form-label',
                ],
            ])
            ->add('message', TextareaType::class, [
                'attr' => [
                    'rows' => 5,
                    'cols' => 40,
                    'class' => 'uk-form-large uk-width-1-1',
                    'placeholder' => 'Please leave me a message, I will get back to you as soon as possible.',
                ],
                'constraints' => [
                    new NotBlank(),
                    new Length([
                        'min' => 20,
                    ]),
                ],
                'label_attr' => [
                    'class' => 'uk-invisible uk-form-label',
                ],
            ])

            ->add('submit', SubmitType::class, [
                'attr' => [
                    'class' => 'uk-button uk-button-large uk-button-primary uk-align-right'
                ],
                'label' => 'Send',

            ])
            ->getForm()
        ;
    }

    /**
     * {@inheritdoc}
     *
     * @param OptionsResolver $resolver
     */
    public function configureOptions (OptionsResolver $resolver)
    {
        $resolver->setDefaults([
            'attr' => [
                'class' => 'uk-form uk-form-horizontal',
            ],
        ]);
    }
}